﻿using UIKit;
using System;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.iOSEdition;

namespace HelloWorld
{
    public partial class HelloWorldViewController : UIViewController
    {
        static bool UserInterfaceIdiomIsPhone
        {
            get { return UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Phone; }
        }

        public HelloWorldViewController(IntPtr handle)
            : base(handle)
        {
        }

        public override void DidReceiveMemoryWarning()
        {
            // Releases the view if it doesn't have a superview.
            base.DidReceiveMemoryWarning();

            // Release any cached data, images, etc that aren't in use.
        }

        #region View lifecycle

        public override void ViewDidLoad()
        {
			try {
				base.ViewDidLoad ();
            	
				MapView mapView = new MapView (View.Frame);
				View.Add (mapView);
            	
				// Set the Map Unit to DecimalDegrees, the Shapefile’s unit of measure. 
				mapView.MapUnit = GeographyUnit.DecimalDegree;
            	
				//WorldMapKitOverlay worldMapKitOverlay = new WorldMapKitOverlay ();
				//mapView.Overlays.Add ("WorldMapKit", worldMapKitOverlay);
            	
				//doOriginal (mapView);
				doTest (mapView);
            	
				// refresh map.
				mapView.Refresh ();

			} catch (Exception ex) {
				Console.WriteLine ("{0}", ex.Message);
			}
        }
		/// <summary>
		/// Test shape files.
		/// </summary>
		/// <param name="mapView">Map view.</param>
		private void doTest(MapView mapView)
		{
			ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"AppData/Countries02.shp");
			worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
			worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

			ShapeFileFeatureLayer.BuildIndexFile (@"AppData/lcc140hp.shp", BuildIndexMode.DoNotRebuild);
			ShapeFileFeatureLayer lcc140hp = new ShapeFileFeatureLayer(@"AppData/lcc140hp.shp");
			lcc140hp.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Water1;
			lcc140hp.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

			LayerOverlay layerOverlay = new LayerOverlay();
			//layerOverlay.Layers.Add(worldLayer);
			layerOverlay.Layers.Add(lcc140hp);

			// testing check - since zero (0) layers being added causes application crash when dragging map!?
			if (layerOverlay.Layers.Count > 0) {
				mapView.Overlays.Add (layerOverlay);
			}

			lcc140hp.Open ();
			mapView.CurrentExtent = lcc140hp.GetBoundingBox ();
			//mapView.CurrentExtent = new RectangleShape(new PointShape(150, -33), new PointShape(152, -34));
			//mapView.CurrentExtent = new RectangleShape(5, 78, 30, 26);
		}
		/// <summary>
		/// Original sample rendering.
		/// </summary>
		/// <param name="mapView">Map view.</param>
		private void doOriginal(MapView mapView)
		{
			ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"AppData/Countries02.shp");
			worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
			worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

			ShapeFileFeatureLayer capitalLayer = new ShapeFileFeatureLayer(@"AppData/WorldCapitals.shp");
			// We can customize our own Style. Here we pass in a color and a size.
			capitalLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.White, 7, GeoColor.StandardColors.Brown);
			// The Style we set here is available from ZoomLevel01 to ZoomLevel05. That means if we zoom in a bit more, it will no longer be visible.
			capitalLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level05;
			capitalLayer.ZoomLevelSet.ZoomLevel06.DefaultPointStyle = PointStyles.Capital3;
			// The Style we set here is available from ZoomLevel06 to ZoomLevel20. That means if we zoom out a bit more, it will no longer be visible.
			capitalLayer.ZoomLevelSet.ZoomLevel06.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

			ShapeFileFeatureLayer capitalLabelLayer = new ShapeFileFeatureLayer(@"AppData/WorldCapitals.shp");
			// We can customize our own TextStyle. Here we pass in the font, size, style and color.
			capitalLabelLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("CITY_NAME", "Arial", 8, DrawingFontStyles.Italic, GeoColor.StandardColors.Black, 3, 3);
			// The TextStyle we set here is available from ZoomLevel01 to ZoomLevel05. 
			capitalLabelLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level05;
			capitalLabelLayer.ZoomLevelSet.ZoomLevel06.DefaultTextStyle = TextStyles.Capital3("CITY_NAME");
			// The TextStyle we set here is available from ZoomLevel06 to ZoomLevel20. 
			capitalLabelLayer.ZoomLevelSet.ZoomLevel06.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
			capitalLabelLayer.DrawingMarginPercentage = 50;

			LayerOverlay layerOverlay = new LayerOverlay();
			layerOverlay.Layers.Add(worldLayer);
			layerOverlay.Layers.Add(capitalLayer);
			layerOverlay.Layers.Add(capitalLabelLayer);

			mapView.Overlays.Add(layerOverlay);
			mapView.CurrentExtent = new RectangleShape(5, 78, 30, 26);
		}

        public override void ViewWillAppear(bool animated)
        {
            base.ViewWillAppear(animated);
        }

        public override void ViewDidAppear(bool animated)
        {
            base.ViewDidAppear(animated);
        }

        public override void ViewWillDisappear(bool animated)
        {
            base.ViewWillDisappear(animated);
        }

        public override void ViewDidDisappear(bool animated)
        {
            base.ViewDidDisappear(animated);
        }

        #endregion
    }
}